@@ -2,7 +2,7 @@ from django.contrib import admin
 
 # Register your models here.
 from .models import CeleryTaskCompleted, CeleryTaskFailed
-
+from .app_settings import CA_LOG_SUCCESS_TO_DB, CA_LOG_FAILURE_TO_DB
 
 class FailedAdmin(admin.ModelAdmin):
     list_display=('task', 'time', 'excep')
@@ -14,5 +14,7 @@ class CompleteAdmin(admin.ModelAdmin):
     date_hierarchy = 'time'
     list_filter=('task',)
 
-admin.site.register(CeleryTaskCompleted, CompleteAdmin)
-admin.site.register(CeleryTaskFailed, FailedAdmin)
+if CA_LOG_SUCCESS_TO_DB:
+    admin.site.register(CeleryTaskCompleted, CompleteAdmin)
+if CA_LOG_FAILURE_TO_DB:
+    admin.site.register(CeleryTaskFailed, FailedAdmin)
