@@ -1,12 +1,11 @@
 from . import urls
 from allianceauth import hooks
-from allianceauth.services.hooks import MenuItemHook, UrlHook
+from allianceauth.services.hooks import UrlHook, MenuItemHook
 
-"""
 class CeleryMenu(MenuItemHook):
     def __init__(self):
-        MenuItemHook.__init__(self, 'Celery',
-                              'fas fa-address-book fa-fw',
+        MenuItemHook.__init__(self, 'Celery Stats',
+                              'fas fa-tasks fa-fw',
                               'celery:celery_mon',
                               navactive=['celery:celery_mon'])
 
@@ -15,15 +14,10 @@ class CeleryMenu(MenuItemHook):
             return MenuItemHook.render(self, request)
         return ''
 
-
-
-
 @hooks.register('menu_item_hook')
 def register_menu():
     return CeleryMenu()
 
-
 @hooks.register('url_hook')
 def register_url():
-    return UrlHook(urls, 'celery', r'^celery/')
-"""
\ No newline at end of file
+    return UrlHook(urls, 'celery', r'^celery/')
\ No newline at end of file
